# -*- coding: utf-8 -*-
""" db_widgets

    Customize forms and grids widgets
    $Id$
    
"""
from datetime import datetime
dbui = local_import('plugin_dbui')

#
# Customize the main viewport
# hide some tables depending on the user role
#
#vm = dbui.ViewportModifier()
#vm.hide_tables('publishers',
#               'categories_aeres',
#               'categories_commission',
#               'collaborations',
#               'countries',
#               'teams',
#               'projects',
#               'publishers')
#
#vm.hide_form_node()
#vm.set_grid_node_name('View')
#
#
# add plugin to all grids
#
dbui.configure_grids(db, plugins=['pGridRowEditor',
                                  'pGridRowEditorContextMenu',
                                  'pGridPaging',
                                  'pGridMathJax'])


#
# Create composite fields for the publication form
#
fm = dbui.FieldModifier('publications')
fm.configure_field('year', maxValue=datetime.now().year)

fm.merge_fields('first_page', 
                'last_page', 
                extjs={'fieldLabel': T('Pages'), 'defaults': {'flex': 1}})

fm.merge_fields('conference_start',
                'conference_end',
                extjs={'fieldLabel': T('Dates'), 'defaults': {'flex': 1}})

#
# Create fieldSet for the publication form
#
pm = dbui.FormModifier('publications')
pm.merge_fields('title',
                'authors',
                'id_collaborations',
                'id_publishers',
                'year',
                'doi',
                'volume',
                'first_page',
                'e_print',
                extjs={'title': T('General'), 'flex': 1})

pm.merge_fields('conference_title',
                'conference_url',
                'conference_start',
                'conference_town',
                'id_countries',
                'conference_speaker',
                spacer=26*3,
                extjs={'title': T('Conference'), 'flex': 1})


pm.merge_fields('authors_cppm',
                'id_teams',
                'id_projects',
                'id_categories_aeres',
                spacer= 26*5,
                extjs={'title': 'CPPM', 'flex': 1})

pm.merge_fields('report_numbers', 
                'id_reports',
                spacer=220,
                extjs={'title': T('Report'), 'flex': 1})

#
# Organize fieldSet within a TabPanel embedded in the publication form
#
pm.set_mapper(dbui.map_tabpanel)

#
# Polish the look and feel of the publication form
# NOTE: the width/height define the size of the window 
# when running the form from the grid. The defaults defines the height
# of the fieldSet allowing a fine tuning of the form layout.
#
pm.configure(buttonAlign='right',
             labelWidth=100,
             labelAlign='right',
             width=400,
             height=380,
             defaults={'height': 320})

#
# Modify the publications grid
#
tpl = ['<b>{PublicationsTitle}</b><br>',
       '{PublicationsAuthors}',
       '<tpl if="PublicationsId_collaborations  &gt; 1">, {CollaborationsCollaboration}</tpl>',
       '<tpl if="PublicationsDoi"><br>{PublicationsDoi}</tpl>',
       '<tpl if="PublicationsId_publishers  &gt; 1"><br>{PublishersAbbreviation}',
           '<tpl if="PublicationsVolume"> {PublicationsVolume}</tpl>',
           '<tpl if="PublicationsYear"> ({PublicationsYear}) </tpl>',
           '<tpl if="PublicationsFirst_page"> {PublicationsFirst_page}</tpl>',
           '<tpl if="PublicationsLast_page">-{PublicationsLast_page}</tpl>',
       '</tpl>',
       '<tpl if="PublicationsE_print"><br>{PublicationsE_print}</tpl>',
       '<tpl if="PublicationsConference_title"><br><br>{PublicationsConference_title}',
           '<tpl if="PublicationsConference_town"><br>{PublicationsConference_town}</tpl>',
           '<tpl if="CountriesCountry">, {CountriesCountry}</tpl>',
           '<tpl if="PublicationsConference_start">, {PublicationsConference_start}</tpl>',
           '<tpl if="PublicationsConference_end"> - {PublicationsConference_end}</tpl>',
           '<tpl if="PublicationsConference_url"><br>{PublicationsConference_url}</tpl>',
           '<br>%s: {PublicationsConference_speaker}' % T('Speaker'),
       '</tpl>',
       '<tpl if="PublicationsReport_numbers"><br><br>',
           '<tpl if="PublicationsId_reports &gt; 1">{ReportsType}, </tpl>',
           '{PublicationsReport_numbers}',
       '</tpl>',
       '<br>Auteurs CPPM : {PublicationsAuthors_cppm}'
       ]

filters = [('year', '==', T('select publication for a given year')),
           ('id_teams', '==', T('select publications for a given team')),
           ('id_projects', '==', T('select publications for a given project')),
           ('id_categories_aeres', '==', T('select publications with a given AERES code')),
           ('authors_cppm', 'contains', T('select publications for a given CPPM author')),
        ]

gm = dbui.GridModifier('publications')
gm.merge_columns('title', 
                 'authors', 
                 'id_collaborations', 
                 'id_publishers',
                 'doi', 
                 'volume',
                 'first_page',
                 'last_page',
                 'e_print',
                 'conference_title',
                 'conference_url',
                 'conference_start',
                 'conference_end',
                 'conference_town',
                 'id_countries',
                 'conference_speaker',
                 'report_numbers',
                 'id_reports',
                 'authors_cppm',
                 autohide=True,
                 position=0,
                 extjs={'header': T('Publication'), 'tpl': tpl, 'width': 700})

gm.set_filters(*filters, extjs={'width': 300})
