""" $Id$

"""

__version__ = "$Revision$"
__author__ = "R. Le Gac"

from gluon.storage import Storage
from modifier import Modifier


VIEWPORT_MODIFIERS = 'viewport_modifiers'

# NOTE
# Persistent data used by the viewport modifier.
# Used by the ViewportModifier class and by the plugin defining default values.
# The extjs key is not needed by the first one since it is in the base class
# but mandatory for the second case. Not a big deal since, the update method 
# is used in viewportModifier.

VIEWPORT_DP = Storage(extjs={},
                      hidden_tables=[],
                      form_node_name= 'Forms',
                      grid_node_name= 'Grids',
                      show_form_node= True,
                      show_grid_node= True) 


class ViewportModifier(Modifier):
    """Helper tool to customize the viewport widget of the application.
    
    """
    
    def __init__(self):
        """Initialize the modifier persistent data.
        
        """
        Modifier.__init__(self, VIEWPORT_MODIFIERS)
        self.data.update(VIEWPORT_DP)


    def hide_form_node(self):
        self.data.show_form_node = False


    def hide_grid_node(self):
        self.data.show_grid_node = False


    def hide_tables(self,*tables):
        """Hide the tables list in arguments.
        Database tables are the children of the form and grid nodes.
        Each table is identified by its database table name.
        
        """
        for el in tables:
            if el not in self.data.hidden_tables:
                self.data.hidden_tables.append(el)


    def set_grid_node_name(self, name):
        self.data.grid_node_name = name


    def set_form_node_name(self, name):
        self.data.form_node_name = name