/**
 * Plugin InTreeForm.
 * 
 * The App.Viewport contains a tree and a tab panels.
 * This plugin add a topNode in the tree which contains child.
 * When a child is clicked a new tab appears in the tab panel.
 * 
 * The name of the child nodes are defined by the property 'nodes'.
 * For example the name of the tables for a database application.
 * 
 * The tab contains a App.form.FormPanel panel. 
 * Its configuration is retrieve from the server.
 * the property wdgCfg allow to add additional configuration property
 * to the form.
 *
 * The ptype of this component is pInTreeForm.
 * 
 * MANDATORY PROPERTIES:
 *      - models
 *      - topNodeName
 *      - nodes
 * 
 * @author legac
 * @extend App.viewport.InTreePanelBase
 * @version $Id$
 * 
 */
Ext.namespace('App.viewport');

App.viewport.InTreePanelForm = Ext.extend(App.viewport.InTreePanelBase, {

    /**
     * private function to instantiate the grid and to add it to the tab
     * 
     * @param {Object} container
     * @param {Object} component
     * @param {Object} index
     */
    addWdg: function (container, component, index) {

        var cfg, 
            table, 
            wdg;
        
        // protection -- add widget when we are concern !				
        if (this.getTopNodeNameFromId(component.id) !== this.topNodeName) {
            return;
        }
        
        // get the name of the table from the tab id
        table = this.getNodeNameFromId(component.id);
        
        // Ask the server the widget configuration and create it
        Dbui.getForm(table, function (provider, response) {
        
            cfg = response.result;
            wdg = Ext.ComponentMgr.create(cfg);		
            
            component.add(wdg);
            component.doLayout();
            
        }, this);
    }
});

Ext.preg('pInTreeForm', App.viewport.InTreePanelForm);
